package org.ddahl.shallot

object CrossCompatibility {

  val doubleOrdering = Ordering.Double.TotalOrdering

}

